<?php
	require_once(CI_PATH_LIBS.'/config.inc.php');
	require_once(CI_PATH_LIBS.'/core.inc.php');

	class CI_CHANNELS_DIVA extends CI_CONFIG
	{
		private $channels_manager;
		
		function CI_CHANNELS_DIVA()
		{
			$this->channels_manager=new CI_CORE_CHANNELS_MANAGER();
			$this->channels_manager->open();
		}
		
		function get_config_file()
		{
			return CORE_PATH_BASE.'/config/drivers/diva.xml';
		}

		function set_flag_reload()
		{
			ci_set_core_flag('channels_manager.reload-diva', '1');
		}

		function get_flag_reload()
		{
			return ci_get_core_flag('channels_manager.reload-diva');
		}

		function get_sys_devices()
		{
			$out=array();
			
			$n=0;
			while (true)
			{
				$n++;
				if (!is_dir("/proc/net/eicon/adapter$n")) break;
				$lines=file("/proc/net/eicon/adapter$n/info");

				$info=array();
				foreach ($lines as $line)
				{
					$line=preg_replace("/[\n\r]+/", '', $line);
					list($k, $v)=preg_split("/\s+:\s+/", $line);

					$info[strtolower($k)]=$v;
				}
				$info['image']=$this->get_image_by_name($info['name']);

				array_push($out, $info);
			}

			return $out;
		}

		function get_image_by_name($name)
		{
			if (preg_match("/V\-BRI\-2/", $name))	return "v-bri-2";
			elseif (preg_match("/4BRI/", $name))	return "v-bri-4";
			elseif (preg_match("/PRI/", $name)) 	return "v-pri";
			elseif (preg_match("/E1/", $name)) 		return "v-pri";
			elseif (preg_match("/T1/", $name)) 		return "v-pri";

			return "generic";
		}
		
		function get_devices()
		{
			$out=array();
			
			$res=$this->channels_manager->ask('diva', 'list_devices');
			foreach ($res['args'] as $k => $v)
			{
				$count++;
				$res2=$this->channels_manager->ask('diva', 'get_device_info', array('n' => $count));

				$res2['args']['image']=$this->get_image_by_name($res2['args']['name']);

				array_push($out, $res2['args']);
			}
		
			return $out;	
		}

		function get_map($info)
		{
			return array(
				'id'				=> $info['id'],
				'composing_timeout'	=> intval($info['composing-timeout']),
				'echo_cancel'		=> $info['echo-cancel']
			);
		}

		function get_rmap($info)
		{
			return array(
				'id'				=> $info['id'],
				'composing-timeout'	=> intval($info['composing_timeout']),
				'echo-cancel'		=> $info['echo_cancel']
			);
		}

		function save_raw_config($array)
		{
			$config =& ci_get_unserialized_xml($this->get_config_file());
			if (!sizeof($array))
				$array2=array();
			else
				$array2['item'] =& $array;

			$config['devices']=$array2;

			$this->set_flag_reload();

			ci_save_xml($this->get_config_file(), $config);
			return ci_response_ok();
		}

		function get_raw_list()
		{
			$config =& ci_get_unserialized_xml($this->get_config_file());
			return ci_normalize_xml_array($config['devices']['item']);
		}

		function get_info($id)
		{
			$info =& parent::get_info($id);
			return $info;
		}

		function task_save($info)
		{
			/* Compose fields */
			$fields=$this->get_rmap($info);

			/* Retrieve item position */
			$n=$this->get_n($info['id']);

			/* Save */
			$list =& $this->get_raw_list();
			$list[$n]=$fields;

			$this->save_raw_config($list);
			return ci_response_ok();
		}
	}
?>