#!/usr/bin/env python

# Copyright and license: Please refer to LICENSE.TXT

import sys
import os
import os.path
import string
import re
import time

_selfpath=(os.path.dirname(os.path.realpath(__file__)).split('/'))[:-1]
_selfpath.append('pylibs')
_libspath='/'.join(_selfpath)
sys.path.append(_libspath)

from castiron import *
from s2p_logger import *

# Variables replace
def set_vars(txt, replace):
	if not txt: txt=""

	for k in replace.keys():

		if not replace[k]: replace[k]=""
		txt=re.sub(r'\$\{'+k+'\}', replace[k], txt)

	return txt

# Check config parameters
CORE_CONF_SYSTEM		= xml_to_array(CORE_PATH_BASE+'/config/system.xml')
CASTIRON_CONF_ALERTS	= xml_to_array(CASTIRON_PATH_BASE+'/config/alerts.xml')

if not CASTIRON_CONF_ALERTS.has_key('credit'): sys.exit(0)

if CASTIRON_CONF_ALERTS['credit']['enabled'] != 'true': sys.exit(0)

# Read from environment
treshold		= int(float(CASTIRON_CONF_ALERTS['credit']['threshold'])*100)
skype_account	= os.environ['from_skype']
balance			= int(os.environ['balance'])
balance_cur		= os.environ['balance_currency']

notified_file = CASTIRON_PATH_BASE+'/data/'+skype_account+'.balancenotified'

# Credit is ok
if balance>treshold:
	if os.path.isfile(notified_file): os.unlink(notified_file)
	sys.exit(0)

# Already notified
if os.path.isfile(notified_file): sys.exit(0)

# Create notified file
fp=open(notified_file, 'w')
fp.write(get_timestamp())
fp.close()

# Email
subject	= CASTIRON_CONF_ALERTS['credit']['message-template-subject']
body	= CASTIRON_CONF_ALERTS['credit']['message-template-body']

# System environ
fp=open('/etc/hostname', 'r')
hostname=re.sub(r'[\n\r]+', '', fp.read())
fp.close()

# Variables
sys_vars={
	'sysname':			CORE_CONF_SYSTEM['hq']['sysname'],
	'account':			skype_account,
	'balance':			("%.2f" % (balance/100)),
	'balance-currency':	balance_cur,
	'threshold':		str(treshold),
	'server':			hostname,
	'hostname':			hostname,
	'date-time':		time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
}

# Replacement
subject	= set_vars(subject, sys_vars)
body	= set_vars(body, sys_vars)

s2p_log("castiron", "warn", "Low credit alert for "+skype_account)

res=ci_media_send({
	'media': 	CASTIRON_CONF_ALERTS['credit']['media'],
	'subject':	subject,
	'body':		body
})

if not res: s2p_log("castiron", "error", "Could not send low credit notification")



